@@ -91,7 +91,7 @@ main(int argc, char **argv) {
     if(xmlSecCryptoDLLoadLibrary(NULL) < 0) {
         fprintf(stdout, "Error: unable to load default xmlsec-crypto library. Make sure\n"
                         "that you have it installed and check shared libraries path\n"
-                        "(LD_LIBRARY_PATH and/or LTDL_LIBRARY_PATH) envornment variables.\n");
+                        "(LD_LIBRARY_PATH and/or LTDL_LIBRARY_PATH) environment variables.\n");
         return(-1);     
     }
 #endif /* XMLSEC_CRYPTO_DYNAMIC_LOADING */
@@ -263,7 +263,7 @@ verify_request(xmlSecKeysMngrPtr mngr) {
         xmlBufferAdd(buffer, buf, ret);
     }
 
-    /* is the document subbmitted from the form? */
+    /* is the document submitted from the form? */
     if(strncmp((char*)xmlBufferContent(buffer), "_xmldoc=", 8) == 0) {
         xmlBufferShrink(buffer, 8);
         buffer->use = url_decode((char*)xmlBufferContent(buffer), xmlBufferLength(buffer)); 
