@@ -148,7 +148,18 @@ xmlSecCryptoDLLibraryCreate(const xmlChar* name) {
 #endif /* XMLSEC_DL_LIBLTDL */
 
 #ifdef XMLSEC_DL_WIN32
+#if !defined(WINAPI_FAMILY) || (WINAPI_FAMILY == WINAPI_FAMILY_DESKTOP_APP)
     lib->handle = LoadLibraryA((char*)lib->filename);
+#else
+    LPWSTR wcLibFilename = xmlSecWin32ConvertUtf8ToUnicode(lib->filename);
+    if(wcLibFilename == NULL) {
+        xmlSecIOError("xmlSecWin32ConvertUtf8ToTstr", lib->filename, NULL);
+        xmlSecCryptoDLLibraryDestroy(lib);
+        return(NULL);
+    }
+    lib->handle = LoadPackagedLibrary(wcLibFilename, 0);
+    xmlFree(wcLibFilename);
+#endif
     if(lib->handle == NULL) {
         xmlSecIOError("LoadLibraryA", lib->filename, NULL);
         xmlSecCryptoDLLibraryDestroy(lib);
@@ -335,7 +346,7 @@ xmlSecCryptoDLInit(void) {
     ret = xmlSecPtrListInitialize(&gXmlSecCryptoDLLibraries,
                                   xmlSecCryptoDLLibrariesListGetKlass());
     if(ret < 0) {
-        xmlSecInternalError("xmlSecPtrListPtrInitialize",
+        xmlSecInternalError("xmlSecPtrListInitialize",
                             "xmlSecCryptoDLLibrariesListGetKlass");
         return(-1);
     }
