@@ -92,7 +92,7 @@ struct _xmlSecMSCryptoHmacCtx {
     const xmlSecMSCryptoProviderInfo  * providers;
     HCRYPTHASH      mscHash;
     unsigned char   dgst[XMLSEC_MSCRYPTO_MAX_HMAC_SIZE];
-    size_t          dgstSize;   /* dgst size in bytes */
+    xmlSecSize      dgstSize;   /* dgst size in bytes */
     int             ctxInitialized;
 };
 
@@ -177,8 +177,6 @@ xmlSecMSCryptoHmacCheckId(xmlSecTransformPtr transform) {
     {
         return(0);
     }
-
-    return(0);
 }
 
 static int
@@ -451,7 +449,7 @@ xmlSecMSCryptoHmacVerify(xmlSecTransformPtr transform,
         return(0);
     }
 
-    /* we check the last byte separatelly */
+    /* we check the last byte separately */
     xmlSecAssert2(dataSize > 0, -1);
     mask = last_byte_masks[ctx->dgstSize % 8];
     if((ctx->dgst[dataSize - 1] & mask) != (data[dataSize - 1]  & mask)) {
